@@ -1,6 +1,7 @@
+from corm.annotations import Set
 from corm.constants import DATETIME_FORMAT
 from corm.datatypes import Transliterator
-from corm.annotations import Set
+from corm.models import CORMUDTBase
 
 from datetime import datetime
 
@@ -18,3 +19,11 @@ DT_MAP = {
     bool: Transliterator(bool, 'BOOLEAN', lambda x: x, lambda x: x),
     float: Transliterator(float, 'DOUBLE', lambda x: x, lambda x: x),
 }
+
+UDT_MAP = {}
+def setup_udt_transliterator(udt: CORMUDTBase) -> Transliterator:
+    if udt._udt_details.udt_key in UDT_MAP.keys():
+        raise NotImplementedError(f'Duplicate Transliterator[{udt}]')
+
+    UDT_MAP[udt] = Transliterator(udt, udt._udt_details.udt_key, lambda x: x, lambda x: x)
+    return UDT_MAP[udt]
